@@ -28,7 +28,7 @@
 #include <ParticleGroup.hpp>
 #include <ParticleGroupManager.hpp>
 
-//using namespace std;
+using namespace std;
 
 const int LEADERBOARD_SIZE = 11; //top-10 plus current score
 
@@ -56,8 +56,6 @@ ScoreKeeper::ScoreKeeper( void):
 		break;
 	}
 	time( & _leaderBoard[ i].time);
-	_leaderBoard[ i].goodiesMissed = 0;
-	_leaderBoard[ i].goodiesCaught = 0;
     }
 }
 
@@ -114,16 +112,6 @@ int ScoreKeeper::addToCurrentScore( int value)
     return newValue;
 }
 
-void ScoreKeeper::incGoodiesCaught( void)
-{
-    _leaderBoard[ _currentIndex].goodiesCaught++;
-}
-
-void ScoreKeeper::incGoodiesMissed( void)
-{
-    _leaderBoard[ _currentIndex].goodiesMissed++;
-}
-
 void ScoreKeeper::updateLeaderBoard( void)
 {
     XTRACE();
@@ -147,19 +135,19 @@ void ScoreKeeper::updateLeaderBoard( void)
 	    ParticleGroupManagerS::instance()->getParticleGroup(EFFECTS_GROUP2);
 	ParticleInfo pi;
 	pi.position.x =  0.0;
-	pi.position.y =-20+3.5f*(_currentIndex+1);
-	pi.position.z =-50.0f;
+	pi.position.y =-20+3.5*(_currentIndex+1);
+	pi.position.z =-50.0;
 	char buf[128];
 	sprintf( buf, "You've climbed to #%d on the leader board!", 
 	    _currentIndex+1) ;
 	pi.text = buf;
 
-	pi.color.x = 0.2f;
-	pi.color.y = 1.0f;
-	pi.color.z = 0.2f;
+	pi.color.x = 0.2;
+	pi.color.y = 1.0;
+	pi.color.z = 0.2;
 
-	pi.extra.y = 0.05f;
-	pi.extra.z = 0.05f;
+	pi.extra.y = 0.05;
+	pi.extra.z = 0.05;
 
 	effects->newParticle( "StatusMessage", pi);
     }
@@ -185,16 +173,7 @@ void ScoreKeeper::dump( void)
 
 	char buf[128];
 	strftime( buf, 127,"%a %d-%b-%Y %H:%M", localtime(&_leaderBoard[i].time));
-	LOG_VOID << " : " << buf;
-
-	int totalGoodies = _leaderBoard[ i].goodiesCaught + _leaderBoard[ i].goodiesMissed;
-	if( totalGoodies > 0)
-	{
-	    sprintf( buf, " (%d%%)", (_leaderBoard[ i].goodiesCaught*100) / totalGoodies);
-	    LOG_VOID << buf;
-	}
-
-	LOG_VOID << endl;
+	LOG_VOID << " : " << buf << endl;
     }
 }
 
@@ -210,14 +189,8 @@ const string ScoreKeeper::getInfoText( unsigned int index)
 	char buf[128];
 	strftime( buf, 127,"%a %d-%b-%Y %H:%M", 
 	    localtime(&_leaderBoard[index].time));
-	info += buf;
 
-	int totalGoodies = _leaderBoard[ index].goodiesCaught + _leaderBoard[ index].goodiesMissed;
-	if( totalGoodies > 0.0f)
-	{
-	    sprintf( buf, " (%d%%)", (_leaderBoard[ index].goodiesCaught*100) / totalGoodies);
-	    info += buf;
-	}
+	info += buf;
     }
 
     return info;
@@ -247,7 +220,7 @@ void ScoreKeeper::load( void)
 	    if( line[0] == '#') continue;
 
 	    ScoreData sData;
-	    Tokenizer  t( line, false, " \t\n\r");
+	    Tokenizer  t( line, " \t\n\r");
 	    string token = t.next();
 	    if( token == "Version")
 	    {
@@ -262,17 +235,6 @@ void ScoreKeeper::load( void)
 			sData.name = token;
 			sData.score = atoi( t.next().c_str());
 			sData.time = (time_t) atoi( t.next().c_str());
-			sData.goodiesCaught = 0;
-			sData.goodiesMissed = 0;
-		        _leaderBoard.push_back( sData);
-		        break;
-
-		    case 2:
-			sData.name = token;
-			sData.score = atoi( t.next().c_str());
-			sData.time = (time_t) atoi( t.next().c_str());
-			sData.goodiesCaught = atoi( t.next().c_str());
-			sData.goodiesMissed = atoi( t.next().c_str());
 		        _leaderBoard.push_back( sData);
 		        break;
 
@@ -305,7 +267,7 @@ void ScoreKeeper::save( void)
 	zoStream zout( outfile);
 
 	zout << "#------LeaderBoard-----#\n";
-	zout << "Version 2\n";
+	zout << "Version 1\n";
 
 	for( unsigned int i=0; i<_leaderBoard.size(); i++)
 	{
@@ -315,10 +277,7 @@ void ScoreKeeper::save( void)
 	    }
 	    zout << _leaderBoard[ i].name << " " 
 	         << _leaderBoard[ i].score << " "
-	         << (long) _leaderBoard[ i].time << " "
-	         << _leaderBoard[ i].goodiesCaught << " "
-	         << _leaderBoard[ i].goodiesMissed << " "
-		 << "\n";
+	         << (long) _leaderBoard[ i].time << "\n";
 	}
     }
 }
@@ -343,27 +302,27 @@ void ScoreKeeper::draw( void)
 	glColor4f(1.0, 1.0, 1.0, 1.0);
 	fontShadow->DrawString( 
 	    buf2, 
-	    250+7, 420-(float)i*36-7, 1.0f, 1.0f);
+	    250+7, 420-i*36-7, 1.0, 1.0);
 	fontShadow->DrawString( 
 	    _leaderBoard[ i].name.c_str(), 
-	    300+7, 420-(float)i*36-7, 1.0f, 1.0f);
+	    300+7, 420-i*36-7, 1.0, 1.0);
 	fontShadow->DrawString( 
 	    buf, 
-	    750-width+9, 420-(float)i*36-9, 1.0f, 1.0f);
+	    750-width+9, 420-i*36-9, 1.0, 1.0);
 
         if( i == _currentIndex)
-	    glColor4f(1.0, 0.852f, 0.0, 1.0);
+	    glColor4f(1.0, 0.852, 0.0, 1.0);
 	else
 	    glColor4f(1.0, 1.0, 1.0, 1.0);
 
 	fontWhite->DrawString( 
 	    buf2, 
-	    250, 420-(float)i*36, 1.0f, 1.0f);
+	    250, 420-i*36, 1.0, 1.0);
 	fontWhite->DrawString( 
 	    _leaderBoard[ i].name.c_str(), 
-	    300, 420-(float)i*36, 1.0f, 1.0f);
+	    300, 420-i*36, 1.0, 1.0);
 	fontWhite->DrawString( 
 		buf, 
-		750-width, 420-(float)i*36, 1.0f, 1.0f);
+		750-width, 420-i*36, 1.0, 1.0);
     }
 }
