@@ -61,8 +61,8 @@ void Selectable::draw( void)
 
     if( _active == this)
     {
-	glColor4f(1.0f, 1.0f, 1.0f, 0.6f);
-	_fontWhite->DrawString( _info.c_str(), 122, 57, 0.7f, 0.65f);
+	glColor4f(1.0, 1.0, 1.0, 0.6);
+	_fontWhite->DrawString( _info.c_str(), 122, 57, 0.7, 0.65);
     }
 }
 
@@ -173,7 +173,7 @@ TextOnlySelectable::TextOnlySelectable(
 
     if( center)
     {
-	_boundingBox.min.x -= width*0.5f;  
+	_boundingBox.min.x -= width*0.5;  
     }
     _boundingBox.max.x = _boundingBox.min.x + width;
     _boundingBox.max.y = _boundingBox.min.y + height;
@@ -238,14 +238,14 @@ FloatSelectable::FloatSelectable(
     const string &variable,
     const string &range): 
 
-    TextOnlySelectable(r, text, info, false, 0.7f, 1.0f, 1.0f, 1.0f),
+    TextOnlySelectable(r, text, info, false, 0.7, 1.0, 1.0, 1.0),
     _variable(variable),
     _startX(-1.0f)
 {
     Tokenizer t(range);
 
-    _min = (float)atof(t.next().c_str());
-    _max = (float)atof(t.next().c_str());
+    _min = atof(t.next().c_str());
+    _max = atof(t.next().c_str());
 
     float curVal = _min;
     ConfigS::instance()->getFloat( _variable, curVal);
@@ -346,9 +346,9 @@ void FloatSelectable::draw( void)
     glColor4f(1.0, 1.0, 1.0, 1.0);
     glEnable(GL_TEXTURE_2D);
     _icons->DrawC( 
-        _slider, _boundingBox.min.x+280, _boundingBox.min.y+15, 1.6f, 0.5f);
+        _slider, _boundingBox.min.x+280, _boundingBox.min.y+15, 1.6, 0.5);
     _icons->DrawC( _doubleArrow, 
-	_boundingBox.min.x+212+_xPos, _boundingBox.min.y+15, 0.8f, 0.8f);
+	_boundingBox.min.x+212+_xPos, _boundingBox.min.y+15, 0.8, 0.8);
     glDisable(GL_TEXTURE_2D);
 }
 
@@ -361,7 +361,7 @@ EnumSelectable::EnumSelectable(
     const string &variable,
     const string &values): 
 
-    TextOnlySelectable(r, text, info, false, 0.7f, 1.0f, 1.0f, 1.0f),
+    TextOnlySelectable(r, text, info, false, 0.7, 1.0, 1.0, 1.0),
     _variable(variable)
 {
     string val;
@@ -428,7 +428,7 @@ void EnumSelectable::draw( void)
 	val.c_str(), 
 	_xOff+9*_size,_boundingBox.min.y-9*_size, 
 	_size, _size); 
-    glColor4f(1.0f, 0.852f, 0.0f, 1.0f);
+    glColor4f(1.0, 0.852, 0.0, 1.0);
 //    glColor4f(r, g, b, 1.0);
     _fontWhite->DrawString( 
 	val.c_str(), 
@@ -444,14 +444,14 @@ BoolSelectable::BoolSelectable(
     const string &info, 
     const string &variable): 
 
-    TextOnlySelectable(r, text, info, false, 0.7f, 1.0f, 1.0f, 1.0f),
+    TextOnlySelectable(r, text, info, false, 0.7, 1.0, 1.0, 1.0),
     _variable(variable)
 {
     _checkmark = _icons->getIndex( "Checkmark");
     _checkmarkOff = _icons->getIndex( "CheckmarkOff");
 
-    _xOff = _boundingBox.max.x + 10.0f;
-    _boundingBox.max.x = _xOff + _icons->getWidth( _checkmark)*0.5f;
+    _xOff = _boundingBox.max.x + 10.0;
+    _boundingBox.max.x = _xOff + _icons->getWidth( _checkmark)*0.5;
 
     _inputBox = _boundingBox;
 }
@@ -521,7 +521,7 @@ LeaderBoardSelectable::LeaderBoardSelectable(
     float width  = _fontWhite->GetWidth( _text.c_str(), _size);
     float height = _fontWhite->GetHeight( _size);
 
-    _boundingBox.min.x -= width*0.5f;  
+    _boundingBox.min.x -= width*0.5;  
     _boundingBox.max.x = _boundingBox.min.x + width;
     _boundingBox.max.y = _boundingBox.min.y + height;
 
@@ -604,7 +604,7 @@ ResolutionSelectable::ResolutionSelectable(
     const string &text,
     const string &info): 
 
-    TextOnlySelectable(r, text, info, false, 0.7f, 1.0f, 1.0f, 1.0f)
+    TextOnlySelectable(r, text, info, false, 0.7, 1.0, 1.0, 1.0)
 {
     _fontShadow = FontManagerS::instance()->getFont( "bitmaps/menuShadow");
 
@@ -668,7 +668,7 @@ ResolutionSelectable::ResolutionSelectable(
     _boundingBox.max.x += 165.0f;
 
     //bounding box for checkmark 
-    _bRect.min.x = _boundingBox.max.x - _icons->getWidth( _checkmark)*0.5f;
+    _bRect.min.x = _boundingBox.max.x - _icons->getWidth( _checkmark)*0.5;
     _bRect.max.x = _boundingBox.max.x;
     _bRect.min.y = _boundingBox.min.y ;
     _bRect.max.y = _bRect.min.y + 30;
@@ -758,7 +758,7 @@ void ResolutionSelectable::draw( void)
 	xOff+_boundingBox.min.x+9*_size,_boundingBox.min.y-9*_size, 
 	_size, _size); 
 
-    glColor4f(1.0f, 0.852f, 0.0f, 1.0f);
+    glColor4f(1.0, 0.852, 0.0, 1.0);
 //    glColor4f(1.0, 1.0, 1.0, 1.0);
     _fontWhite->DrawString( 
 	resolution.c_str(), 
@@ -831,7 +831,7 @@ void TextSelectable::activate( void)
 
 	MenuManagerS::instance()->Goto( this);
 //	    LOG_INFO << "Activate " << _text << endl;
-	_ds = 0.1f;
+	_ds = 0.1;
 
 	AudioS::instance()->playSample( "sounds/beep.wav");
     }
@@ -840,14 +840,14 @@ void TextSelectable::activate( void)
 void TextSelectable::deactivate( void)
 {
 //	LOG_INFO << "Deactivate " << _text << endl;
-    _ds = -0.1f;
+    _ds = -0.1;
 }
 
 void TextSelectable::update( void)
 {
     _prevSize = _size;
     _size += _ds;
-    Clamp( _size, 1.0, 1.8); //any bigger and we'll have overlapping activation areas
+    Clamp( _size, 1.0, 2.0);
 
     //adjust the input box according to the scaled text
     float dx = (float)(_boundingBox.max.x - _boundingBox.min.x) * (_size-1.0f) / 2.0f;
@@ -876,7 +876,7 @@ void TextSelectable::draw( void)
 	_boundingBox.min.x-halfWidth+5*iSize,
 	_boundingBox.min.y-halfHeight-5*iSize, 
 	iSize, iSize); 
-    glColor4f(r, g, b, 0.8f);
+    glColor4f(r, g, b, 0.8);
     _fontWhite->DrawString( 
 	_text.c_str(), 
 	_boundingBox.min.x-halfWidth, _boundingBox.min.y-halfHeight, 
