@@ -108,7 +108,7 @@ bool Video::init( void)
     if( _maxFPS)
     {
 	LOG_INFO << "Video: Restricting FPS to " << _maxFPS << endl;
-	_fpsStepSize = 1.0f/(float)_maxFPS;
+	_fpsStepSize = 1.0/(float)_maxFPS;
     }
 
     ConfigS::instance()->getBoolean( "fullscreen", _isFullscreen);
@@ -198,19 +198,19 @@ bool Video::init( void)
     GLfloat mat_specular[] = { 1.0, 1.0, 1.0, 0.0 };
 */
 
-    GLfloat mat_ambient[]  = { 0.5f, 0.5f, 0.5f, 0.5f };
-    GLfloat mat_diffuse[]  = { 0.4f, 0.4f, 0.4f, 0.5f };
-    GLfloat mat_specular[] = { 0.6f, 0.6f, 0.6f, 0.5f };
-    GLfloat mat_shininess[] = { 60.0f };
+    GLfloat mat_ambient[]  = { 0.5, 0.5, 0.5, 0.5 };
+    GLfloat mat_diffuse[]  = { 0.4, 0.4, 0.4, 0.5 };
+    GLfloat mat_specular[] = { 0.6, 0.6, 0.6, 0.5 };
+    GLfloat mat_shininess[] = { 60.0 };
     glMaterialfv(GL_FRONT, GL_SPECULAR, mat_specular);
     glMaterialfv(GL_FRONT, GL_SHININESS, mat_shininess);
     glMaterialfv(GL_FRONT, GL_AMBIENT, mat_ambient);
     glMaterialfv(GL_FRONT, GL_DIFFUSE, mat_diffuse);
 
-    GLfloat mat_diffuse_b[]  = { 0.5f, 0.5f, 0.5f, 0.5f };
-    GLfloat mat_ambient_b[]  = { 0.3f, 0.3f, 0.3f, 0.5f };
-    GLfloat mat_specular_b[] = { 0.2f, 0.2f, 0.2f, 0.5f };
-    GLfloat mat_shininess_b[] = { 10.0f };
+    GLfloat mat_diffuse_b[]  = { 0.5, 0.5, 0.5, 0.5 };
+    GLfloat mat_ambient_b[]  = { 0.3, 0.3, 0.3, 0.5 };
+    GLfloat mat_specular_b[] = { 0.2, 0.2, 0.2, 0.5 };
+    GLfloat mat_shininess_b[] = { 10.0 };
     glMaterialfv(GL_BACK, GL_SPECULAR, mat_specular_b);
     glMaterialfv(GL_BACK, GL_SHININESS, mat_shininess_b);
     glMaterialfv(GL_BACK, GL_AMBIENT, mat_ambient_b);
@@ -326,12 +326,12 @@ void  Video::updateSettings( void)
 bool Video::update( void)
 {
     //    XTRACE();
-    static float nextTime = Timer::getTime()+0.5f;
+    static float nextTime = Timer::getTime()+0.5;
     float thisTime = Timer::getTime();
     if( thisTime > nextTime)
     {
 	updateSettings();
-	nextTime = thisTime+0.5f;
+	nextTime = thisTime+0.5;
     }
 
     if( _maxFPS)
@@ -366,7 +366,7 @@ bool Video::update( void)
     glMatrixMode(GL_PROJECTION);
     glLoadIdentity();
 
-    const float fov = 53.13f;
+    const float fov = 53.13;
     glFrustum( 
         (4.0/3.0)*(-2.0*tan(53.13 * M_PI / 360.0)),  //xmin
         (4.0/3.0)*( 2.0*tan(53.13 * M_PI / 360.0)),  //xmax
@@ -392,9 +392,9 @@ bool Video::update( void)
 	//highlight the playing field, useful when using mouselook
 	glDisable( GL_DEPTH_TEST);
 	glDisable( GL_LIGHTING);
-	float y = tan(((float)M_PI*fov)/360.0f)*100;
-	float x = y*4.0f/3.0f;
-	glColor4f( 1.0f, 1.0f, 1.0f, 0.1f );
+	float y = tan((M_PI*fov)/360.0)*100;
+	float x = y*4.0/3.0;
+	glColor4f( 1.0, 1.0, 1.0, 0.1 );
 	glBegin(GL_QUADS);
 	    glVertex3f( -x, y, -100);
 	    glVertex3f(  x, y, -100);
@@ -446,12 +446,12 @@ bool Video::update( void)
     {
 	if( !HeroS::instance()->alive())
 	{
-	    glColor4f(1.0f,1.0f,1.0f,0.8f);
-	    smallFont.DrawString( "GAME OVER" , 80, 320, 4.0f, 4.0f);
+	    glColor4f(1.0,1.0,1.0,0.8);
+	    smallFont.DrawString( "GAME OVER" , 80, 320, 4.0, 4.0);
 
-	    glColor4f(1.0f,0.0f,0.0f,0.8f);
+	    glColor4f(1.0,0.0,0.0,0.8);
 	    smallFont.DrawString( "Too dangerous for ya? Try again!" , 
-		215, 260, 1.0f, 1.0f);
+		215, 260, 1.0, 1.0);
 
             if( ScoreKeeperS::instance()->currentIsTopTen())
 	    {
@@ -460,24 +460,24 @@ bool Video::update( void)
 		    _textInput.turnOn();
 		}
 
-		glColor4f(1.0f,1.0f,1.0f,1.0f);
-		smallFont.DrawString( "Top Ten Finish! RIP",215,200, 1.0f, 1.0f);
+		glColor4f(1.0,1.0,1.0,1.0);
+		smallFont.DrawString( "Top Ten Finish! RIP",215,200, 1.0, 1.0);
 
 		string pname = "Enter Pilot name: ";
 		pname += _textInput.getText()+"_";
-		glColor4f(1.0f,0.852f,0.0f,1.0f);
-		smallFont.DrawString( pname.c_str() , 215, 140, 1.0f, 1.0f);
+		glColor4f(1.0,0.852,0.0,1.0);
+		smallFont.DrawString( pname.c_str() , 215, 140, 1.0, 1.0);
 
 		ScoreKeeperS::instance()->setName( _textInput.getText());
 	    }
 	    else
 	    {
 		string moremorequickquick = "Press right mouse button to restart";
-		glColor4f(1.0f,0.852f,0.0f,1.0f);
-		smallFont.DrawString( moremorequickquick.c_str() , 215, 140, 1.0f, 1.0f);
+		glColor4f(1.0,0.852,0.0,1.0);
+		smallFont.DrawString( moremorequickquick.c_str() , 215, 140, 1.0, 1.0);
 	    }
 
-	    glColor4f(1.0f,1.0f,1.0f,1.0f);
+	    glColor4f(1.0,1.0,1.0,1.0);
 	}
     }
 
@@ -489,7 +489,7 @@ bool Video::update( void)
 	float thisTime = Timer::getTime();
 	if( thisTime > nextShow)
 	{
-	    nextShow = thisTime + 0.5f;
+	    nextShow = thisTime + 0.5;
 	    aCount = ParticleGroupManagerS::instance()->getAliveCount();
 	}
 	sprintf( buff, "p=%d", aCount);
@@ -505,18 +505,18 @@ bool Video::update( void)
 
 	_titleA->bind();
 	glBegin(GL_QUADS);
-	glTexCoord2f( dx     ,dx );   glVertex3f(350,740, z);
-	glTexCoord2f( 1.0f-dx,dx );   glVertex3f(500,740, z);
-	glTexCoord2f( 1.0f-dx,1-dx ); glVertex3f(500,560, z);
-	glTexCoord2f( dx     ,1-dx ); glVertex3f(350,560, z);
+	glTexCoord2f( dx    ,dx );   glVertex3f(350,740, z);
+	glTexCoord2f( 1.0-dx,dx );   glVertex3f(500,740, z);
+	glTexCoord2f( 1.0-dx,1-dx ); glVertex3f(500,560, z);
+	glTexCoord2f( dx    ,1-dx ); glVertex3f(350,560, z);
 	glEnd();
 
 	_titleB->bind();
 	glBegin(GL_QUADS);
-	glTexCoord2f( dx     ,dx );   glVertex3f(500,740, z);
-	glTexCoord2f( 1.0f-dx,dx );   glVertex3f(650,740, z);
-	glTexCoord2f( 1.0f-dx,1-dx ); glVertex3f(650,560, z);
-	glTexCoord2f( dx     ,1-dx ); glVertex3f(500,560, z);
+	glTexCoord2f( dx    ,dx );   glVertex3f(500,740, z);
+	glTexCoord2f( 1.0-dx,dx );   glVertex3f(650,740, z);
+	glTexCoord2f( 1.0-dx,1-dx ); glVertex3f(650,560, z);
+	glTexCoord2f( dx    ,1-dx ); glVertex3f(500,560, z);
 	glEnd();
 
 	glDisable(GL_TEXTURE_2D);
@@ -525,12 +525,12 @@ bool Video::update( void)
 
 	glColor4f(1.0,1.0,1.0,0.5);
 	string gVersion = "v"+GAMEVERSION;
-	float width = smallFont.GetWidth( gVersion.c_str(), 0.6f);
-	smallFont.DrawString( gVersion.c_str() , 995.0f-width, 5.0f, 0.6f, 0.4f);
+	float width = smallFont.GetWidth( gVersion.c_str(), 0.6);
+	smallFont.DrawString( gVersion.c_str() , 995.0-width, 5.0, 0.6, 0.4);
     }
     else
     {
-	float boardWidth = (float)_board->getWidth( _boardIndex);
+	float boardWidth = _board->getWidth( _boardIndex);
 
 	if( _boardVisible && (_boardPosX<0))
 	{
@@ -546,10 +546,10 @@ bool Video::update( void)
         //draw board if at least partially visible
         if( _boardPosX > -boardWidth)
 	{
-	    float size = 0.48f;
-	    float tdy = -36.0f;
-	    float ty = (float)VIDEO_ORTHO_HEIGHT-56.0f;
-	    float tx = 28.0f+_boardPosX;
+	    float size = 0.48;
+	    float tdy = -36.0;
+	    float ty = VIDEO_ORTHO_HEIGHT-56.0;
+	    float tx = 28.0+_boardPosX;
 
 
 	    glEnable(GL_TEXTURE_2D);
@@ -568,12 +568,12 @@ bool Video::update( void)
 
 	    float he = HeroS::instance()->getEnergy();
 	    if( he<0.0) he=0.0;
-	    glColor4f( 1.0f, 0.1f, 0.1f, 0.5f );
+	    glColor4f( 1.0, 0.1, 0.1, 0.5 );
 	    glBegin(GL_QUADS);
-		glVertex3f( tx        , ty+2, -1);
-		glVertex3f( tx+he*.97f, ty+2, -1);
-		glVertex3f( tx+he*.97f, ty+20, -1);
-		glVertex3f( tx        , ty+20, -1);
+		glVertex3f( tx,    ty+2, -1);
+		glVertex3f( tx+he*.97, ty+2, -1);
+		glVertex3f( tx+he*.97, ty+20, -1);
+		glVertex3f( tx,    ty+20, -1);
 	    glEnd();
 	    glColor4f(1.0,1.0,1.0,0.5);
 
@@ -582,12 +582,12 @@ bool Video::update( void)
 	    ty+=tdy;
 
 	    float se = HeroS::instance()->getShieldEnergy();
-	    glColor4f( 1.0f, 0.8f, 0.0f, 0.5f );
+	    glColor4f( 1.0, 0.8, 0.0, 0.5 );
 	    glBegin(GL_QUADS);
-		glVertex3f( tx        , ty+2, -1);
-		glVertex3f( tx+se*.97f, ty+2, -1);
-		glVertex3f( tx+se*.97f, ty+20, -1);
-		glVertex3f( tx        , ty+20, -1);
+		glVertex3f( tx,    ty+2, -1);
+		glVertex3f( tx+se*.97, ty+2, -1);
+		glVertex3f( tx+se*.97, ty+20, -1);
+		glVertex3f( tx,    ty+20, -1);
 	    glEnd();
 	    glColor4f(1.0,1.0,1.0,0.5);
 
@@ -596,12 +596,12 @@ bool Video::update( void)
 	    ty+=tdy;
 
 	    float we = HeroS::instance()->getWeaponEnergy();
-	    glColor4f( 0.2f, 1.0f, 0.2f, 0.5f );
+	    glColor4f( 0.2, 1.0, 0.2, 0.5 );
 	    glBegin(GL_QUADS);
-		glVertex3f( tx        , ty+2, -1);
-		glVertex3f( tx+we*.97f, ty+2, -1);
-		glVertex3f( tx+we*.97f, ty+20, -1);
-		glVertex3f( tx        , ty+20, -1);
+		glVertex3f( tx,    ty+2, -1);
+		glVertex3f( tx+we*.97, ty+2, -1);
+		glVertex3f( tx+we*.97, ty+20, -1);
+		glVertex3f( tx,    ty+20, -1);
 	    glEnd();
 	    glColor4f(1.0,1.0,1.0,0.5);
 	    
