@@ -22,7 +22,6 @@
 #include <GameState.hpp>
 #include <Endian.hpp>
 #include <ResourceManager.hpp>
-#include <GetDataPath.hpp>
 
 void checkEndian( void)
 {
@@ -42,7 +41,7 @@ void showInfo()
     LOG_INFO << GAMETITLE << " " << GAMEVERSION 
              << " - "__TIME__" "__DATE__
              << endl;
-    LOG_INFO << "Copyright (C) 2001-2005 by Frank Becker" << endl;
+    LOG_INFO << "Copyright (C) 2001-2004 by Frank Becker" << endl;
     LOG_INFO << "Visit http://criticalmass.sourceforge.net" << endl;
     LOG_INFO << "----------------------------------" << endl;
 }
@@ -68,19 +67,10 @@ int main( int argc, char *argv[])
 
     checkEndian();
     if( !ResourceManagerS::instance()->
-	  addResourcePack("resource.dat", getDataPath()))
+	  addResourcePack("resource.dat", DATA_DIR))
     {
-	LOG_WARNING << "resource.dat not found. Trying data directory." << endl;
-#ifdef VCPP
-	ResourceManagerS::instance()->addResourceDirectory( "..\\data");
-#else
-	ResourceManagerS::instance()->addResourceDirectory( "data");
-#endif
-	if( ResourceManagerS::instance()->getResourceSize("system/config.txt") < 0)
-	{
-	    LOG_ERROR << "Sorry, unable to find game data!" << endl;
-	    return -1;
-	}
+	LOG_WARNING << "resource.dat not found." << endl;
+//        return -1;
     }
 
     Config *cfg = ConfigS::instance();
@@ -101,6 +91,12 @@ int main( int argc, char *argv[])
 	cfg->dump();
     }
 
+    string resourceDir;
+    if( cfg->getString( "overrideResourceFile", resourceDir))
+    {
+	ResourceManagerS::instance()->addResourceDirectory( resourceDir);
+    }
+
     // get ready!
     if( GameS::instance()->init())
     {
