@@ -33,13 +33,9 @@ _ValT* findHash(
 template< class _KeyT, class _ValT >
 _ValT* findHash( 
     const _KeyT &trigger, 
-#if (__INTEL_COMPILER >= 700)
     hash_map< _KeyT, _ValT*, hash<_KeyT>, equal_to<_KeyT> > & hashMap )
-#else
-    hash_map< const _KeyT, _ValT*, hash<const _KeyT>, equal_to<const _KeyT> > & hashMap )
-#endif
 {
-    typename hash_map< const _KeyT, _ValT*, hash<const _KeyT> >::const_iterator ci;
+    typename hash_map< _KeyT, _ValT*, hash<_KeyT> >::const_iterator ci;
     ci = hashMap.find( trigger);
     if( ci == hashMap.end())
     {
